# CIS 122 - Final Project
# Lara Letaw
# 081806

import random
import time

class Inventory:

    def __init__(self):
        self.inventory = {}

    # Index something in the inventory
    def add(self, key, value):
        self.inventory[key] = value

    # Remove something from the inventory
    def remove(self, key):
        del self.inventory[key]

    # Print out the inventory
    def show(self):
        print self.inventory

    # Get the length of the dictionary
    def getLength(self):
        return len(self.inventory)

    # Print out the length of the dictionary
    def printLength(self):
        print len(self.inventory)

    # Print out the inventory keys (items)
    def printKeys(self):
        keys = self.inventory.keys()
        for key in keys:
            print "\t"+key

    # Lookup a key in the inventory to find its value
    def getValue(self, key):
        return self.inventory[key]

    # Return the values in the inventory
    def getValues(self):
        return self.inventory.values()

    # Print the value of a key in the inventory
    def printValue(self, key):
        print self.inventory[key]

    # Return the keys in the inventory
    def getKeys(self):
        return self.inventory.keys()

# Have somethinng where if the user says something, the mob will do something
# Inventory of the word-triggers and the mob responses
class Mob:

    def __init__(self, mob_filename):

        # The passed-in mob filename
        self.mobname = mob_filename

        # The name of the mob, without mob_ but with other underscores
        self.main_mobname = mob_filename[4:]

        # The name of the mob, without mob_ and underscores
        self.clean_mobname = self.stripUnderscore(self.main_mobname)

        # Open, read, and split into sections (divided by ***)
        open_file = open(self.mobname + ".txt")
        read_file = open_file.read()
        split_file = read_file.split("\n\n***\n\n")

        # Get the description, without the <desc> tags
        raw_desc = split_file[0]
        raw_desc_end = len(raw_desc)-8
        self.desc = raw_desc[7:raw_desc_end]

        # Get the start room, without the <start> tags
        raw_start = split_file[1]
        raw_start_end = len(raw_start)-9
        self.room = raw_start[8:raw_start_end]

        # The list of items/item descriptions for the mob, without tags
        raw_items = split_file[2]
        raw_items_end = len(raw_items)-9
        items = raw_items[8:raw_items_end]

        # Inventory of the mob
        self.mob_inventory = Inventory()

        # If there are items in the mob inventory...        
        if len(items) > 0:

            # Split into item/item desc pairs 
            split_items = items.split("\n")

            # Add each item into the mob inventory
            for line in split_items:

                # Split into item and item desc
                split_items_again = line.split("\t")

                # The item
                item = split_items_again[0]

                # The item description
                item_desc = split_items_again[1]

                # Put the items in the dictionary
                self.mob_inventory.add(item, item_desc)

        # Get the mob interactions, without the <inters> tags
        raw_inters = split_file[3]
        raw_inters_end = len(raw_inters)-10
        inters = raw_inters[9:raw_inters_end]

        # Interaction database of the mob
        self.mob_inters = Inventory()

        # If there are mob interactions available...
        if len(inters) > 0:

            # Split into trigger/response pairs
            split_inters = inters.split("\n")

            # Split each trigger/response pair into trigger and response
            for line in split_inters:
                split_inters_again = line.split("\t")

                # The mob trigger
                trigger = split_inters_again[0]

                # The mob response
                response = split_inters_again[1]

                # Add the interactions to the mob interaction dictionary
                self.mob_inters.add(trigger, response)

    # Take underscores out of a string
    def stripUnderscore(self, name):
        if "_" in name:
            name = name.replace("_", " ")
        else:
            pass

        return name

    # Print the name of the mob, without mob_ and underscores
    def printMob(self):
        print "\n"+self.clean_mobname

    # Get the mob's current room
    def getRoom(self):
        return self.room
    
    # Get the filename of the mob (without extension)
    def getFilename(self):
        return self.mobname

    # Get the name of the mob, without mob_ and underscores
    def getName(self):
        return self.clean_mobname

    # Print the description of the mob
    def printDesc(self):
        print "\n"+self.desc

    # Get the description of the mob
    def getDesc(self):
        return self.desc

    # Print what the mob says
    def mobTalk(self, sentence):
        print self.clean_mobname+' says: '+'"'+sentence+'"'
        print

    # Give an item to the user
    def mobGive(self, item, user_inventory):
        # Put the item in the user inventory
        item_desc = self.mob_inventory.getValue(item)
        user_inventory.add(item, item_desc)

        # Take the item out of the mob inventory
        self.mob_inventory.remove(item)
                
        print self.clean_mobname+" gives you a "+item

    # Take an item from the user
    def mobTake(self, item, user_inventory):
        # Put the item in the mob inventory
        item_desc = user_inventory.getValue(item)
        self.mob_inventory.add(item, item_desc)

        # Take the item out of the mob inventory
        user_inventory.remove(item)
                
        print self.clean_mobname+" took the "+item+" away from you."

    # Pick up an item from the room
    def mobGet(self, item, current_room):
        # Put the item in the mob inventory
        item_desc = current_room.dict_items.getValue(item)
        self.mob_inventory.add(item, item_desc)

        # Take the item out of the mob inventory
        current_room.dict_items.remove(item)
                
        print self.clean_mobname+" gets the "+item+"."
        
class Room:

    def __init__(self, room_filename):

        # The room filename, with room_ and underscores
        self.roomname = room_filename

        # The room filename, without room_
        self.clean_roomname = room_filename[5:]

        # Split up the sections of the file (desc, exits, items, etc.)
        open_file = open(self.roomname + ".txt")
        read_file = open_file.read()
        split_file = read_file.split("\n\n***\n\n")

        # Get the description, without the <desc> tags
        raw_desc = split_file[0]
        raw_desc_end = len(raw_desc)-8
        self.desc = raw_desc[7:raw_desc_end]

        # Get the exits, without the <exits> tags
        raw_exits = split_file[1]
        raw_exits_end = len(raw_exits)-9
        exits = raw_exits[8:raw_exits_end]

        # If exits exist in the room file, go put them in the exits dictionary.
        # Also, have an abbreviation dictionary so users can just type
        # the first letter of the direction to go that direction.
        if len(exits) > 0:
            split_exits = exits.split("\n")

            self.dict_exits = {}
            self.dict_exits_abbrev = {}

            for line in split_exits:
                split_exits_again = line.split("\t")
                direction = split_exits_again[0]
                destination = split_exits_again[1]
                self.dict_exits[direction] = destination
                first_letter = direction[0]
                self.dict_exits_abbrev[first_letter] = direction
                
        # If there aren't any exits in the room file, the exits dictionary
        # will start out empty.
        else:
            self.dict_exits = {}

        # Get the items, without the <items> tags
        raw_items = split_file[2]
        raw_items_end = len(raw_items)-9
        items = raw_items[8:raw_items_end]

        # Dictionary of items in the room
        self.dict_items = Inventory()
    
        if len(items) > 0:
            split_items = items.split("\n")

            for line in split_items:
                split_items_again = line.split("\t")
                item = split_items_again[0]
                item_desc = split_items_again[1]
                self.dict_items.add(item, item_desc)

        # The inventory of mobs in the room.  Starts out empty, mobs are
        # indexed by the external indexMob function.
        self.dict_mobs = Inventory()

    # Print out the name of the room
    def printRoomname(self):
        print "\n"+self.stripUnderscore(self.clean_roomname)

    # Return the name of the room
    def getRoomname(self):
        return self.stripUnderscore(self.clean_roomname)

    # Print out the room description
    def printDesc(self):
        print "\n"+self.desc+"\n"

    # Set the room description
    def setDesc(self, new_desc):
        self.desc = new_desc

    # Show what mobs are in the room
    def printMobs(self):
        if self.dict_mobs.getLength() != 0:
            keys = self.dict_mobs.getKeys()
            for key in keys:
                print key+" is here."
            print

    # Print the items that are in the room
    def printItems(self):
        if self.dict_items.getLength() != 0:
            keys = self.dict_items.getKeys()
            for key in keys:
                if key[0].lower() != "a":
                    print "There is a "+key+" here."
                else:
                    print "There is an "+key+" here."
            print

    # Take underscores out of a name
    def stripUnderscore(self, name):
        if "_" in name:
            name = name.replace("_", " ")
        else:
            pass

        return name

    # Return the room exit directions
    def getExitDirections(self):
        return self.dict_exits.keys()

    # Print out the room exits    
    def printExits(self):
        if self.dict_exits == {}:
            pass
        else:
            keys = self.dict_exits.keys()
            for key in keys:
                destination = self.dict_exits[key]
                print key.capitalize()+": "+self.stripUnderscore(destination[5:])
            print

    # Figure out where the destination room will be
    def getRoom(self, direction):
        if direction in self.dict_exits_abbrev.keys():
            full_dir = self.dict_exits_abbrev[direction]
            destination = self.dict_exits[full_dir]
        else:
            destination = self.dict_exits[direction]

        return destination

    # Check if the user is moving in a valid direction
    def checkValid(self, command):
        valid_dir = True
        
        if command in self.dict_exits:
            pass
        elif command in self.dict_exits_abbrev:
            pass
        else:
            valid_dir = False
    
        return valid_dir

# Isolate each line of the file
def fileSplitter(filename):
    open_file = open(filename)
    read_file = open_file.read()
    split_file = read_file.split("\n")
    return split_file

# Put the mobs in their start rooms
def indexMob(mob, dictionary):
    # Name of the start room
    startroom_name = mob.getRoom()

    # The actual start room
    startroom = dictionary[startroom_name]

    # Name of the mob (the passed-in mob is the acutal mob)
    mob_name = mob.getName()
        
    # Put the mob in the mob inventory for the room -- name and actual mob
    startroom.dict_mobs.add(mob_name, mob)

# Move a mob to a different room randomly
def moveMobs(mob, dictionary, current_room):
    
    # The mob has a 50% change of moving
    options = ["stay", "go"] 
    chosen_option = random.choice(options)
    if chosen_option == "go":

        # Name of the mob's current room
        mob_roomname = mob.getRoom()

        # Actual current room
        mob_room = dictionary[mob_roomname]

        # Placeholder for old room
        old_room = mob_room

        # Name of the mob (key for room mob-inventory)
        mob_name = mob.getName()
        
        # Take the mob out of the old room mob-inventory
        mob_room.dict_mobs.remove(mob_name)
        
        # Figure out the possible exit directions
        exits = mob_room.getExitDirections()
            
        # Choose a direction at random
        chosen_direction = random.choice(exits)

        # Mob's new room
        new_roomname = mob_room.dict_exits[chosen_direction]

        # Put the mob in the new room
        mob.room = new_roomname

        # Actual new room
        new_room = dictionary[new_roomname]
        
        # Put the mob into the new room mob-inventory
        new_room.dict_mobs.add(mob_name, mob)

        # If the mob moves into the current room, display a notification
        if new_room == current_room:
            print mob_name+" has arrived."

        # If the mob moves out of the current room, display a notification
        if old_room == current_room and old_room != new_room:
            print mob_name+" has left."
       
# Display the room name, desc, exits
def roomdisplayShort(room):
    room.printRoomname()
    room.printDesc()
    room.printMobs()
    room.printExits()

# Display the room, and everything in it
def roomdisplayAll(room):
    room.printRoomname()
    room.printDesc()
    room.printMobs()
    room.printItems()
    room.printExits()

# Split the room_list file into individual lines
split_roomfile = fileSplitter("roomlist.txt")

# Dictionary of rooms (format room name : actual room)
room_list = {}

# Creat each room and put in the room dictionary
for line in split_roomfile:
    string = line+"="+"Room"+"('"+line+"')"
    exec string
    dict_string = "room_list['"+line+"']="+line
    exec dict_string

# Split the mob_list file into individual lines
split_mobfile = fileSplitter("moblist.txt")

# Dictionary of mobs (format mob name : actual mob)
mob_list = {}

# Create each mob and put in the mob dictionary
for line in split_mobfile:
    
    # Create the mob
    string = line+"="+"Mob"+"('"+line+"')"
    exec string

    # Index the mob in the mob dictionary
    dict_string = "mob_list['"+line+"']="+line
    exec dict_string

# Index all mobs into their start room
for mob_name in mob_list:
    mob = mob_list[mob_name]
    indexMob(mob, room_list)

# Item inventory of the user
user_inventory = Inventory()

# Knowledge base (what the user knows thus far)
knowledge_inventory = Inventory()

# List of user commands
command_list = ["look", "get", "drop", "inv", "say", "zap", "chop", "jump", "help", "quit"]

# The room the user starts in
current_room = room_list["room_254_Deschutes"]

# Number of times the stump at Rotten Tree Stump has been chopped
chops = 0

# Prompt user to enter a name
enter_name = raw_input("What is your name, traveler?\n")
user_name = enter_name

# Display only what's in the roomdisplayShort function
roomdisplayShort(current_room)

time.sleep(1.5)

# Intro text
mob_Zieter_Vernouth.mobTalk(
'''Hello, '''+user_name+''', and welcome to Typhon.
I am Zieter Vernouth, overseer of this world.

We are in great danger, and I believe you can help us.  Please let me tell
you about how my world was sickened to this grave condition...

Not long ago, a powerful, good-intentioned but altogether careless being made
a horrible mistake.  And what was this mistake?  Look around you.

To you this may seem like a world merely experiencing a foggy day, but as
you explore Typhon, you will realize that every tree, every creature, and
indeed every atom of matter has been condemned to drabness.

It is your quest to undo this bunglement and return the color to Typhon once
again.  To do this, you will need to find something of great superiority and
drop it at the feet of our ruler, The Teefanii.  

But I must warn you, there are serious perils in this world...

This is all I can tell you now.  However, there is one last way in which I can
assist you.  Take this small gift, and use it wisely.

Now please go, before it's too late!''')

# Give the Zapper to the user
mob_Zieter_Vernouth.mobGive("Zapper", user_inventory)

while True:

    # If the user is in the Tent and has $649 + and adobe brick,
    # the Pack Man will just take it
    if current_room.getRoomname() == "Tent of the Pack Man":
        if "$649 bill" in user_inventory.getKeys():
            if "adobe brick" in user_inventory.getKeys():
                mob_Pack_Man.mobTake("$649 bill", user_inventory)
                mob_Pack_Man.mobTake("adobe brick", user_inventory)
                mob_Pack_Man.mobTalk("One pretty package, coming right up!")
                time.sleep(1)
                mob_Pack_Man.mobGive("Pretty Package", user_inventory)
    
    # User types what they want to do
    command = raw_input("> ")

    # Help file
    if command[0:4].lower() == "help":
        print "Possible commands:"
        for item in command_list:
            print "\t"+item

    # Command for looking at items
    elif command[0:4].lower() == "look":

        # Everything after the word 'look'
        look_item = command[5:]

        # If the user types more than 'look', do these things
        if len(command) > 4:
            
            # Check if the user is looking at an item
            if look_item in current_room.dict_items.getKeys():
                current_room.dict_items.printValue(look_item)

            # Check if the user is looking in user inventory
            elif look_item in user_inventory.getKeys():
                user_inventory.printValue(look_item)

            # Check if the user is looking at a mob
            elif look_item in current_room.dict_mobs.getKeys():
                actual_mob = current_room.dict_mobs.getValue(look_item)
                actual_mob.printDesc()

                # If the mob doesn't have any items, don't do anything
                if actual_mob.mob_inventory.getLength() == 0:
                    pass

                # If the mob has items, display what they are
                else:
                    print "\n"+look_item+" is carrying:"
                    actual_mob.mob_inventory.printKeys()
                    
            # If the item isn't in the room or inventory, display this message
            else:
                print "That's not here."
                
        # If the user just types 'look', display everything in the room 
        else:
            roomdisplayAll(current_room)
    
    # Command for picking up objects
    elif command[0:3].lower() == "get":
        if len(command) > 3:
            item_get = command[4:]

            # Check if the item is in the room inventory
            if item_get in current_room.dict_items.getKeys():

                # Description of the item
                itemdesc_get = current_room.dict_items.getValue(item_get)

                # Remove the item from the item dictionary of the room
                current_room.dict_items.remove(item_get)

                # Add the item to the user inventory
                user_inventory.add(item_get, itemdesc_get)
                print "You now have "+item_get+"."

            # If the user picks the coyote, it is converted into an object
            elif item_get == "A gimpy coyote":
                user_inventory.add(item_get, mob_A_gimpy_coyote.getDesc())
                current_room.dict_mobs.remove("A gimpy coyote")
                del mob_list["mob_A_gimpy_coyote"]
                print "You now have a "+item_get+"."

            # Check if the user is trying to get a mob
            elif item_get in current_room.dict_mobs.getKeys():
                print "You attempt to get "+item_get+" but fail miserably!"

            # Display this if user tries to get something that's not there    
            else:
                print "That's not here."

        # Display this is the user only types 'get'
        else:
            print "Get what?"

    # Command for dropping items
    elif command[0:4].lower() == "drop":

        # Go through this if the user types more than 'drop'
        if len(command) > 4:

            # Everything after the word 'drop'
            item_drop = command[5:]

            # The description of the item
            itemdesc_drop = user_inventory.getValue(item_drop)

            # Check if the dropped item is in the user inventory
            if item_drop in user_inventory.getKeys():

                # If the user drops the Golden Grahams in the Bog,
                # Alathea will get them and give advice in return
                if item_drop == "Box of Golden Grahams":
                    if current_room.getRoomname() == "Bog":
                        mob_Alathea_the_Bog_Creature.mobTake("Box of Golden Grahams", user_inventory)
                        mob_Alathea_the_Bog_Creature.mobTalk("Yummmmmmm!!!!!")
                        print "Alathea the Bog Creature mounches the yummy Golden Grahams!"
                        time.sleep(2)
                        print "Still mounching..."
                        time.sleep(2)
                        mob_Alathea_the_Bog_Creature.mobTalk("Thank you... so very much...")
                        time.sleep(2)
                        mob_Alathea_the_Bog_Creature.mobTalk("In return, I offer you this advice...")
                        time.sleep(2)
                        mob_Alathea_the_Bog_Creature.mobTalk("Take what you can GET!")

                # The user can't drop the coyote unless they are in
                # the castle.  If the user drop the coyote in the castle, they
                # will win the game.
                elif item_drop == "A gimpy coyote":
                    if current_room.getRoomname() == "The Silver Castle of The Teefanii":
                        # Take the item out of the user inventory
                        user_inventory.remove(item_drop)
                        
                        print "You dropped the "+item_drop+"."
                        mob_The_Teefanii.mobTalk("Ohh what a darling coyote!!!")
                        mob_The_Teefanii.mobTalk("Yes, this is just exactly what I need!")
                        print "The saturation of the world is adjusted."
                        time.sleep(1)
                        print "The hue of the world is adjusted."
                        time.sleep(1)
                        print "The lightness of the world is adjusted."
                        time.sleep(1)
                        print
                        print "Everything is back to normal!!"
                        print
                        print "Congratulations!  You did it!"
                        time.sleep(1.5)
                        print "...you hear laughter from across the world..."
                        time.sleep(1)
                        print 'Zieter Vernouth laughs: "Mwahahhahaha!!!  It was me all along!\nHoho, did I sure trick you!"'
                        print
                        time.sleep(2)
                        print "Oh dear..."
                        time.sleep(1)
                        print "Thanks for playing!"
                        time.sleep(3)
                        break
                        
                    else:
                        print "The gimpy coyote clings tight and refuses to be dropped"

                else:

                    # Take the item out of the user inventory
                    user_inventory.remove(item_drop)
                    
                    # Add the item into the item dictionary for the room
                    current_room.dict_items.add(item_drop, itemdesc_drop)
                    print "You dropped the "+item_drop+"."

                    # If the user drops the Pretty Package in the Castle,
                    # Linus Torvalds will appear to warn against using it
                    if item_drop == "Pretty Package":
                        if current_room.getRoomname() == "The Silver Castle of The Teefanii":
                            mob_The_Teefanii.mobTalk("Wonderful!  You found it!  Thank you!")
                            mob_The_Teefanii.mobGet("Pretty Package", current_room)
                            time.sleep(1)
                            print "\nLinus Torvalds suddenly bursts through the door!\n"
                            time.sleep(1)
                            print 'Linus Torvalds yells: "Nooo!!!  You must not use it!!  You must seek out freedom and free-ness!"\n'
                            time.sleep(1)
                            mob_The_Teefanii.mobTalk("Blargh... oh well...")
                            time.sleep(1)
                            mob_The_Teefanii.mobTalk("I'm sorry, but I cannot take this!")
                            mob_The_Teefanii.mobGive("Pretty Package", user_inventory)
                            print 'Linus Torvalds says: "Phew, thanks..."'
                            print
                            print "Linus Torvalds disappears."
                        
            # If the item is not in the inventory, display this
            else:
                print "You don't have that."

        # If the user only types 'drop', display this
        else:
            print "Drop what?"

    # Command for viewing the inventory
    elif command.lower() == "inv" or command.lower() == "inventory":

        # If the user isn't carrying anything...
        if user_inventory.getLength() == 0:
            print "You aren't carrying anything!"

        # If the user is carrying items, display them
        else:
            print "You are carrying:"
            user_inventory.printKeys()

    # Command for saying things
    elif command[0:3].lower() == "say":
        if len(command) > 3:

            # Everything after the word 'say'
            said_words = command[4:]
            
            # Output what the user said
            print 'You say: "'+said_words+'"'

            # Check if the command is in the mob interaction inventory
            for mob_name in mob_list:

                # The actual mob
                mob = mob_list[mob_name]

                # If the mob is in the current room...
                if mob.room == current_room.roomname:

                    # Find what triggers the mob to do something
                    mob_triggers = mob.mob_inters.getKeys()

                    # Check if what the user said triggers a mob response
                    for trigger in mob_triggers:
                        if trigger in said_words:
                            exec mob.mob_inters.getValue(trigger)
        else:
            print "Say what?"
    
    # Command for zapping people
    elif command[0:3].lower() == "zap":
        if len(command) > 3:

            zapped_person = command[4:]

            if "Zapper" in user_inventory.getKeys():
                if zapped_person in current_room.dict_mobs.getKeys():
                    
                    # King Graham is the only person who can be zapped --
                    # and when he is zapped, he turns into Golden Grahams
                    if zapped_person == "King Graham":
                        print "\nZAAAAPPP!!!!"
                        time.sleep(1)
                        print "\nKing Graham is no longer here."
                        
                        # Remove King Graham from the current room
                        current_room.dict_mobs.remove("King Graham")

                        # Remove King Graham from the mob dictionary
                        del mob_list["mob_King_Graham"]
                        
                        time.sleep(1)
                        print "\nAhhhh!!!  What did you do???!!"
                        time.sleep(1)
                        print "\nYou just zapped King Graham!!"
                        time.sleep(1)

                        # Put Golden Grahams in the room
                        current_room.dict_items.add("Box of Golden Grahams", "Oh\
                        yum!  These look scrumptious!  Probably someone who is\
                        forced to eat fruit all day would like these...")
                         
                    else:
                        print "Nothing happens when you zap "+zapped_person+"!"
                else:
                    print zapped_person+" isn't here."
            else:
                print "You need a zapper before you can do that!"

        else:
            print "Zap what?"

    # The user can only jump somewhere if they are on The Last Limb
    elif command[0:4].lower() == "jump":
        if current_room.getRoomname() == "The Last Limb":
            current_room = room_list["room_Other_Side_of_the_Hedge"]
            roomdisplayShort(current_room)
        else:
            print "Wheee!!"

    # Command for chopping the stump
    elif command[0:4].lower() == "chop":
        if len(command) > 4:
            
            chopped_thing = command[5:].lower()

            # The user needs an axe in order to chop 
            if "Axe" in user_inventory.getKeys():
                if chopped_thing == "stump":
                    if current_room.getRoomname() == "Rotten Tree Stump":
                        if chops < 7:
                            print "You start chopping the stump...\n"
                            time.sleep(1.5)
                            print "This stump needs a bit more work."
                            chops += 1
                        elif chops == 7:
                            print "Phew!  The stump is finally gone!\n"
                            mob_A_babbling_old_man.mobTake("Axe", user_inventory)
                            print
                            mob_A_babbling_old_man.mobTalk("Well thanks very much!  Here's your money!")
                            mob_A_babbling_old_man.mobGive("$649 bill", user_inventory)
                            current_room.setDesc("There used to be a stump here, now it's gone!")
                            mob_A_babbling_old_man.mob_inters.remove("work")
                    else:
                        print "There isn't a stump here!"
                else:
                    print "You can't chop anything but the stump!"
            else:
                print "You need an axe to do that!"

        else:
            print "Chop what?"
    
    # Command for quitting the program
    elif command.lower() == "quit" or command.lower() == "q":

        # Ask user to confirm quit
        print "Noooo!!!  Are you sure you want to quit??"
        confirm_quit = raw_input("> ")

        # If the user says 'no' or 'n', don't get out of the program
        if confirm_quit.lower() == "no" or confirm_quit.lower() == "n":
            print "Oh, goody!"
            continue

        # If the user types anything besides 'no' or 'n', close program
        else:
            print "See you next time..."
            break

    # Check if the user is wanting to move to a different room
    elif current_room.checkValid(command.lower()):

        # Move the user to where they want to go
        lookup_dest = current_room.getRoom(command.lower())

        # Change the current room to the new room
        current_room = room_list[lookup_dest]

        # Display short version of the room
        roomdisplayShort(current_room)

    # If the input cannot be interpreted...
    else:
        print "Huh?  What do you want to do?"

    # Move the mob around
    if "Zieter Vernouth" not in current_room.dict_mobs.getKeys():
        moveMobs(mob_Zieter_Vernouth, room_list, current_room)

    # Only move the gimpy coyote if he isn't an object yet
    if "mob_A_gimpy_coyote" in mob_list:
        if "A gimpy coyote" not in current_room.dict_mobs.getKeys():
            moveMobs(mob_A_gimpy_coyote, room_list, current_room)





